/**
 * Copyright (c) 2000-2011 Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.calendar.service.permission;

import com.liferay.calendar.model.CalendarEvent;
import com.liferay.calendar.service.CalendarEventLocalServiceUtil;
import com.liferay.portal.kernel.exception.PortalException;
import com.liferay.portal.kernel.exception.SystemException;
import com.liferay.portal.security.auth.PrincipalException;
import com.liferay.portal.security.permission.PermissionChecker;

/**
 * @author Eduardo Lundgren
 * @author Michael C. Han
 */
public class CalendarEventPermission {

	public static void check(
			PermissionChecker permissionChecker, CalendarEvent calendarEvent,
			String actionId)
		throws PortalException {

		if (!contains(permissionChecker, calendarEvent, actionId)) {
			throw new PrincipalException();
		}
	}

	public static void check(
			PermissionChecker permissionChecker, long calendarEventId,
			String actionId)
		throws PortalException, SystemException {

		if (!contains(permissionChecker, calendarEventId, actionId)) {
			throw new PrincipalException();
		}
	}

	public static boolean contains(
		PermissionChecker permissionChecker, CalendarEvent calendarEvent,
		String actionId) {

		if (permissionChecker.hasOwnerPermission(
				calendarEvent.getCompanyId(), CalendarEvent.class.getName(),
				calendarEvent.getCalendarEventId(), calendarEvent.getUserId(),
				actionId)) {

			return true;
		}

		return permissionChecker.hasPermission(
			calendarEvent.getGroupId(), CalendarEvent.class.getName(),
			calendarEvent.getCalendarEventId(), actionId);
	}

	public static boolean contains(
			PermissionChecker permissionChecker, long calendarEventId,
			String actionId)
		throws PortalException, SystemException {

		CalendarEvent calendarEvent =
			CalendarEventLocalServiceUtil.getCalendarEvent(calendarEventId);

		return contains(permissionChecker, calendarEvent, actionId);
	}

}